---
title: zfs project
keywords: documentation
layout: documentation
sidebar: _sidebar
toc: false
---
## Overview

This type allows you to manage a project on a ZFS appliance.

Here is an example on how to use this:

    zfs_project { 'default:all/project_1':
      ensure              => 'present',
      aclinherit          => 'restricted',
      aclmode             => 'discard',
      checksum            => 'fletcher4',
      compression         => 'off',
      default_group       => 'other',
      default_permissions => '705',
      default_user        => 'nobody',
      mountpoint          => '/export/project_1',
      quota               => '0.0',
      recordsize          => '131072.0',
      reservation         => '0.0',
      sharenfs            => 'on',
      sharesmb            => 'on',
      snapdir             => 'hidden',
    }

## Attributes



Attribute Name                                          | Short Description                                                            |
------------------------------------------------------- | ---------------------------------------------------------------------------- |
[aclinherit](#zfs_project_aclinherit)                   | Specifies the ACL inheritance behavior.                                      |
[aclmode](#zfs_project_aclmode)                         | Specifies the ACL mode.                                                      |
[appliance](#zfs_project_appliance)                     | The name of the appliance to connect to.                                     |
[atime](#zfs_project_atime)                             |     Specifies weather you want to update access time on read.                |
[checksum](#zfs_project_checksum)                       | Specifies the ACL inheritance behavior.                                      |
[compression](#zfs_project_compression)                 | Specifies the type of compression of off.                                    |
[default_group](#zfs_project_default_group)             |     Specifies the default group id for a file.                               |
[default_permissions](#zfs_project_default_permissions) |     Specifies the default permissions for a file.                            |
[default_sparse](#zfs_project_default_sparse)           |     Specifies the ACL inheritance behavior.                                  |
[default_user](#zfs_project_default_user)               |      Specifies the default user for a file.                                  |
[ensure](#zfs_project_ensure)                           | The basic property that the resource should be in.                           |
[maxblocksize](#zfs_project_maxblocksize)               |     Specifies the maximum blocksize for the project and/or the share.        |
[mountpoint](#zfs_project_mountpoint)                   |     Specifies the mount point .                                              |
[name](#zfs_project_name)                               | The full name of the project.                                                |
[pool_name](#zfs_project_pool_name)                     | The  storage pool name of the project.                                       |
[project_name](#zfs_project_project_name)               | The  project name of the project or share.                                   |
[provider](#zfs_project_provider)                       | resource.                                                                    |
[quota](#zfs_project_quota)                             |     Specifies the quota on the disk or share.                                |
[readonly](#zfs_project_readonly)                       |     Specifies if the project is readonly or not.                             |
[recordsize](#zfs_project_recordsize)                   |     Specifies the record size of the project or share.                       |
[reservation](#zfs_project_reservation)                 |     Specifies the reservation size for the project or share.                 |
[sharedav](#zfs_project_sharedav)                       |     Specifies if the project or share must be shared with the DAV protocol.  |
[shareftp](#zfs_project_shareftp)                       |     Specifies if the project or share must be shared with the FTP protocol.  |
[sharenfs](#zfs_project_sharenfs)                       | Specifies if the project or share must be shared with the NFS protocol.      |
[sharesftp](#zfs_project_sharesftp)                     |     Specifies if the project or share must be shared with the FTP protocol.  |
[sharesmb](#zfs_project_sharesmb)                       |     Specifies if the project or share must be shared with the SMB protocol.  |
[sharetftp](#zfs_project_sharetftp)                     |     Specifies if the project or share must be shared with the TFTP protocol. |
[snapdir](#zfs_project_snapdir)                         |      Specifies the snapdit behaviour of the project or share.                |




### aclinherit<a name='zfs_project_aclinherit'>

Specifies the ACL inheritance behavior.

    zfs_...{
      ...
      aclinhert => 'restricted'
      ...
    }

At the moment it accepts the following values:

- discard'
- noallow'
- restricted'
- passthrough
- passthrough-x


[Back to overview of zfs_project](#attributes)


### aclmode<a name='zfs_project_aclmode'>

Specifies the ACL mode.

    zfs_...{
      ...
      aclmode => 'discard'
      ...
    }

At the moment it accepts the following values:

- discard
- mask
- passthrough


[Back to overview of zfs_project](#attributes)


### appliance<a name='zfs_project_appliance'>

The name of the appliance to connect to.

This is the first part of the title and is seperated from the rest with a double colon.

    zfs_...{appliance:...
      ...
    }


[Back to overview of zfs_project](#attributes)


### atime<a name='zfs_project_atime'>

    Specifies weather you want to update access time on read.

zfs_...{
  ...
  atime => true
  ...
}

Valid values are `true`, `false`. 
[Back to overview of zfs_project](#attributes)


### checksum<a name='zfs_project_checksum'>

Specifies the ACL inheritance behavior.

    zfs_...{
      ...
      checksum => 'fletcher2'
      ...
    }

At the moment it accepts the following values:
- fletcher2
- fletcher4
- sha256


[Back to overview of zfs_project](#attributes)


### compression<a name='zfs_project_compression'>

Specifies the type of compression of off.

    zfs_...{
      ...
      compression => 'lzjb'
      ...
    }

At the moment it accepts the following values:

- off
- lzjb
- gzip-2
- gzip
- gzip-9


[Back to overview of zfs_project](#attributes)


### default_group<a name='zfs_project_default_group'>

    Specifies the default group id for a file.

zfs_...{
  ...
  default_group => 'unknown'
  ...
}


[Back to overview of zfs_project](#attributes)


### default_permissions<a name='zfs_project_default_permissions'>

    Specifies the default permissions for a file.

zfs_...{
  ...
  default_permissions => '0700'
  ...
}


[Back to overview of zfs_project](#attributes)


### default_sparse<a name='zfs_project_default_sparse'>

    Specifies the ACL inheritance behavior.

zfs_...{
  ...
  default_sparse => true
  ...
}

Valid values are `true`, `false`. 
[Back to overview of zfs_project](#attributes)


### default_user<a name='zfs_project_default_user'>

     Specifies the default user for a file.

zfs_...{
  ...
  default_user => 'unknown'
  ...
}


[Back to overview of zfs_project](#attributes)


### ensure<a name='zfs_project_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of zfs_project](#attributes)


### maxblocksize<a name='zfs_project_maxblocksize'>

    Specifies the maximum blocksize for the project and/or the share.

zfs_...{
  ...
  maxblocksize => 'restricted'
  ...
}

Valid values are `absent`. Values can match `/^\-?\d*\.?\d*$/`.
[Back to overview of zfs_project](#attributes)


### mountpoint<a name='zfs_project_mountpoint'>

    Specifies the mount point .

zfs_...{
  ...
  mountpoint => '/export/my_share'
  ...
}


[Back to overview of zfs_project](#attributes)


### name<a name='zfs_project_name'>

The full name of the project.


[Back to overview of zfs_project](#attributes)


### pool_name<a name='zfs_project_pool_name'>

The  storage pool name of the project.

This is the second part of the title.

    zfs_...{appliance:pool/....:
      ...
    }


[Back to overview of zfs_project](#attributes)


### project_name<a name='zfs_project_project_name'>

The  project name of the project or share.

This is the third part of the title.

    zfs_...{appliance:pool/project....:
      ...
    }


[Back to overview of zfs_project](#attributes)


### provider<a name='zfs_project_provider'>

The specific backend to use for this `zfs_project`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage a project on a ZFS appliance


[Back to overview of zfs_project](#attributes)


### quota<a name='zfs_project_quota'>

    Specifies the quota on the disk or share.

zfs_...{
  ...
  quota => '1G'
  ...
}


[Back to overview of zfs_project](#attributes)


### readonly<a name='zfs_project_readonly'>

    Specifies if the project is readonly or not.

zfs_...{
  ...
  readonly => true
  ...
}

Valid values are `true`, `false`. 
[Back to overview of zfs_project](#attributes)


### recordsize<a name='zfs_project_recordsize'>

    Specifies the record size of the project or share.

zfs_...{
  ...
  recordsize => '1000'
  ...
}

Valid values are `absent`. Values can match `/^\-?\d*\.?\d*$/`.
[Back to overview of zfs_project](#attributes)


### reservation<a name='zfs_project_reservation'>

    Specifies the reservation size for the project or share.

zfs_...{
  ...
  reservation => '100'
  ...
}

Valid values are `absent`. Values can match `/^\-?\d*\.?\d*$/`.
[Back to overview of zfs_project](#attributes)


### sharedav<a name='zfs_project_sharedav'>

    Specifies if the project or share must be shared with the DAV protocol.

zfs_...{
  ...
  sharedav => 'on'
  ...
}


[Back to overview of zfs_project](#attributes)


### shareftp<a name='zfs_project_shareftp'>

    Specifies if the project or share must be shared with the FTP protocol.

zfs_...{
  ...
  shareftp => 'on'
  ...
}


[Back to overview of zfs_project](#attributes)


### sharenfs<a name='zfs_project_sharenfs'>

Specifies if the project or share must be shared with the NFS protocol.

You can set it to:

- On (nfs share mode rw, no exceptions)
- Off (nfs share mode none, no exceptions)
- ro (nfs share mode ro, no exceptions)
- An String detailled describing the share mode with possibility for e.g. network level exceptions etc., e.g.:
sec=sys,ro,nosuid,nosub,rw=@2.3.4.5/32:@1.2.3.4/32,root=@2.3.4.5/32:@1.2.3.4/32:@6.7.8.9/32

    zfs_...{
      ...
      sharenfs => 'on'
      ...
    }


[Back to overview of zfs_project](#attributes)


### sharesftp<a name='zfs_project_sharesftp'>

    Specifies if the project or share must be shared with the FTP protocol.

zfs_...{
  ...
  sharesftp => 'on'
  ...
}


[Back to overview of zfs_project](#attributes)


### sharesmb<a name='zfs_project_sharesmb'>

    Specifies if the project or share must be shared with the SMB protocol.

zfs_...{
  ...
  sharesmb => 'on'
  ...
}


[Back to overview of zfs_project](#attributes)


### sharetftp<a name='zfs_project_sharetftp'>

    Specifies if the project or share must be shared with the TFTP protocol.

zfs_...{
  ...
  sharetftp => 'on'
  ...
}


[Back to overview of zfs_project](#attributes)


### snapdir<a name='zfs_project_snapdir'>

     Specifies the snapdit behaviour of the project or share.

zfs_...{
  ...
  snapdir => 'true'
  ...
}


[Back to overview of zfs_project](#attributes)

