#
# See the file "LICENSE" for the full license governing this code.
#
module Puppet_X
  module EnterpriseModules
    class RestfullPath

      VARIABLE_REGEXP = /\%\{(.*)\}/

      def initialize(path)
        @path = path
      end

      def contains_variables?
        !@path.scan(VARIABLE_REGEXP).empty?
      end

      def unassigned(path)
        result = []
        current_segments = path.split('/') - ['']
        segments.each_with_index do | segment, i|
          variable_name = segment.scan(VARIABLE_REGEXP).flatten.first
          current_value = current_segments[i]
          result << variable_name.to_sym if variable_name && !current_value
        end
        result
      end

      def variables(path)
        result = {}
        current_segments = path.split('/') - ['']
        segments.each_with_index do | segment, i|
          variable_name = segment.scan(VARIABLE_REGEXP).flatten.first
          current_value = current_segments[i]
          result[variable_name.to_sym] = current_value if variable_name && current_value
        end
        result
      end

      def subst(hash)
        filled_in_segments = []
        segments.each do |segment|
          begin
            filled_in_segments << segment % hash
          rescue KeyError
            break
          end
        end
        "/#{filled_in_segments.join('/')}"
      end

      def segments
        @path.split('/') - ['']
      end

      def ==(string)
        @path == string
      end

      def to_s
        @path
      end
    end
  end
end
 